@@ -66,9 +66,12 @@ class Excel:
         :param sheet_name:
         :return:
         """
-        sheet_name = sheet_name if sheet_name else self.sheet_name
-        ws = self.wb_xlrd.sheet_by_name(sheet_name)
-        return str(ws.cell(*self.get_cell(cell)).value)
+        try:
+            sheet_name = sheet_name if sheet_name else self.sheet_name
+            ws = self.wb_xlrd.sheet_by_name(sheet_name)
+            return str(ws.cell(*self.get_cell(cell)).value).replace('\xa0', '')
+        except (Exception,):
+            return ''
 
     def get_color(self, cell) -> ColorObject:
         """
@@ -80,7 +83,7 @@ class Excel:
         hex_color = ws[cell].fill.start_color.index
         hex_color = f'#{hex_color[2:]}'
         rgb_color = webcolors.hex_to_rgb(hex_color)
-        rgb_color = [rgb_color.red, rgb_color.green, rgb_color.blue]
+        rgb_color = (rgb_color.red, rgb_color.green, rgb_color.blue)
         color_name = self.closest_color(rgb_color)
 
         return ColorObject(hex_color, rgb_color, color_name)
@@ -131,12 +134,24 @@ class Excel:
                 if num_of_rows:
                     if len(data) >= num_of_rows:
                         break
+            except (IndexError, AttributeError):
+                if not data:
+                    print(f'Check if the cell {start_cell} to # of columns is not all empty!')
+                break
             except (Exception,):
                 break
             i += steps
 
         return data
 
+    def get_last(self) -> tuple:
+        """
+        Returns the last cells
+        :return:
+        """
+        ws = self.wb_openpyxl[self.sheet_name]
+        return str(ws.max_row), str(ws.max_column)
+
     @staticmethod
     def convert_to_dict(data: list, key_idx: int, header_idx: int = 0) -> dict:
         """
